%Initialization of all model parameters for mechanical drive compressor system

%general
clear all;
time0 = 0.0;            %starting time (needed because of possible time lookup tables)
nsave = 100;            %length of simulation output vectors saved in scopes
out_decim = 50;         %frequency of saving data in 'saveout' blocks
deltat = 2e-4;          %simulation time step
trun = 600.0;           %length of simulation run
rair = 287.;            %air ideal gas constant
cp_air = 1006.;         %air constant pressure specific heat
cv_air = 719.;          %air constant volume specific heat
r_h2o = 461.5043;       %H2O vapor ideal gas constant
c08 = -5.8002206e+003;  %one of constants for calculating saturated water vapor pressure from temperature
c09 = 1.3914993;        %one of constants for calculating saturated water vapor pressure from temperature
c10 = -4.8640239E-02;   %one of constants for calculating saturated water vapor pressure from temperature
c11 = 4.1764768E-05;    %one of constants for calculating saturated water vapor pressure from temperature
c12 = -1.4452093E-08;   %one of constants for calculating saturated water vapor pressure from temperature
c13 = 6.5459673;        %one of constants for calculating saturated water vapor pressure from temperature
bulkpervol = 4e9;       %artifical bulk modulus per actual volume
mdotglobal = 0.03;      %global mass flow rate initialization
factor1 = 0.001;        %transport lines convergence coeff 1 for plates
factor3 = 2.0;          %transport lines convergence coeff 1 for transport lines
%setting up property lookup tables
load R134a_files/lookup_s_vs_pt01;  %load s vs. p,T lookup tables for compressor
s_lookupsvspt = s1;     %entropy [J/kg/K]
p_lookupsvspt = p1*1e5; %pressure [Pa]
t_lookupsvspt = t1;     %temperature [K]
load R134a_files/lookup_h_vs_ps01;  %load h vs. p, s lookup table for compressor
h_lookuphvsps = h1;     %enthalpy [J/kg]
p_lookuphvsps = p1*1e5; %pressure [Pa]
s_lookuphvsps = s1;     %specific entropy [J/kg/K]
load R134a_files/lookup_sat_vs_t02; %load saturated properties vs. T table 
t_lookupsgsatvst = t1;  %temperature [K]
s_lookupsgsatvst = sg;  %enthropy of saturated vapor [J/kg/K]
load R134a_files/lookup_sat_vs_t01; %load psat vs. T table
t_lookup_tsatvsp = t1;         %temperature [K]
p_lookup_tsatvsp = psat*1e5;   %saturation pressure [Pa]

%ambient conditions, lookup tables
t_ambient = 303.16;     %ambient temperature
p_ambient = 1.013e5;    %ambient pressure
rh_ambient = 50.0;      %percent ambient relative humidity
time_ambvstime = [0 1e5];                %time vector for ambient vs. time lookup tables
p_ambvstime = [p_ambient p_ambient];     %ambient pressure vector for ambient pressure vs. time lookup table
t_ambvstime = [t_ambient t_ambient];     %ambient temperature vector for ambient temperature vs. time lookup table
rh_ambvstime = [rh_ambient rh_ambient];  %relative humidity [%] vector for ambient RH vs. time lookup table
set_steadystate=0.0;    %0 for transient, 1 for turning off compressor cycling

%Controls
ifmech = 1.0;           % 0.0: electric drive compressor and controls,  1.0:  mechanical drive compressor and controls
init_picontr1 = 0.23;   %initialization for PI controller #1 integrator (blower speed control)
init_picontr2 = 0.32;   %initialization for PI controller #2 integrator (compr. rpm control) 
init_memrestart= 2250.; %initialization compr. rpm control switch back on
tevap_target = 273.16+3.0;      %evaporator temperature target used to set compressor speed
mrefr_targ=0.48;        %target total refrigerant mass
mrefr_outrate=0.2;      %rate at which excess refrigerant mass is removed 

%Cabin model
tairevapout_limit = 274.;   %if evap.out air temperature goes above this, turn on compressor.  Only for ifmech = 1
dt_evapout = 0.5;       %when when evap. out air temperature goes below tairevapout_limit-dt_evapout, turn off compressor. Only for ifmech = 1
onoffinit_evap = 1.0;   %initial on/off signal from tair_evapout control. Only for ifmech = 1
vel_vehicle = 20.0;     %vehicle velocity [m/s]
time_velvstime = [0 1e5];                  %time vector for vehicle velocity vs. time lookup table
vel_velvstime = [vel_vehicle vel_vehicle]; %velocity vector for vehicle velocity vs. time lookup table
load velvstimeSC03;              %overwrite previous time_velvstime and vel_velvstime from m-file for SC03 cycle
vol_cabin = 3.0;        %air volume of the cabin
pinit_cabin = 102000.;  %cabin initial pressure
tinit_cabin = 313.16;   %cabin initial temperature
rhinit_cabin = 40.;     %cabin initial relative humidity in percents
ttarg_cabin = 293.;     %cabin desired temperature, turn on compressor when tcabin > ttarg_cabin
dt_thermostat = 0.2;    %turn off compressor when tcabin < ttarg_cabin-dt_thermostat.  Matter only when ifmech = 1.0.
onoffinit_cabin = 1.0;  %initialization whether cooling is on (1.0) or off (0.0). Matters only when ifmech =1 and in dt_thermostat band
setting_recirc = -1.0;  %fraction of total blower mass flow rate coming from cabin. Set to -1 for auto control
k_cabinleakin = 1e-4;   %constant for outside air to leak into cabin. m3/s = k* dP
k_cabinleakout = 4e-4;  %constant for cabin air to leak to the outside. m3/s = k* dP
hmax_heater = 8000.;    %maximum heat flow rate from the heater into air stream downstream of evaporator
setting_blend = 0.0;    %heat addition to blower stream = setting_blend * hmax_heater
l_cabinsurf = 2.0;      %length of cabin surface area for convective heat transfer with outside
w_cabinsurf = 1.8;      %width of cabin surface area for convective heat transfer with outside
shape_cabinsurf = 0.5;  %multiplier to heat transfer coeff based on deviation from flat plate surface
thmass_cabinint =2e5;   %thermal mass of cabin interior (like seats, dashboard etc)
tinit_cabinint =313.16; %initial temperature of cabin interior
htrans_cabinint = 25.;  %heat transfer coefficient between cabin air and cabin interior
area_cabinint = 8.0;    %area for heat transfer between cabin air and cabin interior
thmass_cabinshell = 1e5;  %thermal mass of cabin outside shell
tinit_cabinshell =308.16; %initial temperature of cabin outside shell
htrans_cabinshell = 15.;%Heat transfer coefficient between cabin air and cabin outside shell
area_cabinshell = 4.0;  %Area for heat transfer between cabin outside shell and cabin air and ambient air
time_solarintvstime = [0 1e5];                              %time vector for solar heat rate to cabin interior vs. time lookup table
htin_solarint = 300.0;                                      %Solar heat rate on cabin interior
htin_solarintvstime = [htin_solarint htin_solarint];        %solar heat rate for solar heat rate to cabin interior vs. time lookup table
htin_solarshell = 1000.0;                                   %Solar heat rate on cabin shell
time_solarshellvstime = [0 1e5];                            %time vector for solar heat rate to cabin shell vs. time lookup table
htin_solarshellvstime = [htin_solarshell htin_solarshell];  %solar heat rate for solar heat rate to cabin shell vs. time lookup table
htin_enginecomp = 0.0;  %Heat addition from engine compartment
setting_blower = 3.0;   %Blower discrete flow setting, 0, 1, 2 or 3. Matters only when ifmech = 1.0
scfm_blower = [0, 100., 200., 300.];    %flow rates [SCFM] for blower curve
dp_blower =   [0,  40., 160., 360.];    %pressure rises for blower curve
f1_blowcontr = -0.7;     %first coefficient for blower controller (affects both P and I) 
f2_blowcontr = 0.005;    %second coefficient for blower controller (affects only I)

%condenser upstream volume (header)
vol_condu = 0.1e-3;      %volume [m3]
pinit_condu = 20e5;      %initial pressure [Pa]. (not always, see initialization rules)
%tinit_condu = 350.0;     %initial temperature [K]. (not always, see initialization rules)
tinit_condu = bulkpervol*vol_condu;    %artificial bulk modulus
hspecinit_condu = 4.5e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_condu = 0.0;     %initial liquid volume fraction. (not always, see initialization rules)

%condenser common input
nparch_cond = 15.;       %number of parallel channels per plate (flat tube)
l_cond = 0.646;          %length of plates/flat tubes (dimension in the direction of refrigerant flow)
achan_cond = 0.7e-3*0.77e-3;             %refrigerant flow cross sectional area of parallel channels
pchan_cond = 2.0*0.7e-3+2.0*0.77e-3;     %refrigerant side perimeter of parallel channels
relrough_cond = 0.01;    %relative roughness of the flat tube channels refrigerant side
mwall_cond = 0.0455;     %dry mass of one plate including fins
cpwall_cond = 900.0;     %specific heat of wall material (set for aluminum)
qcfactor_cond = 0.0;     %axial wall heat conduction coefficient
wplate_cond = 16.8e-3;   %plate width (dimension in air flow direction)
gappl_cond = 6.68e-3;    %distance between two plates / flat tubes
lfin_cond = 1.1*6.68e-3; %length of one fin between two plates. Equals gappl for straight 90 degree fin.
tp_cond = 8.5e-3;        %pitch of plates (top surface to top surface), has to be greater than gappl
thfin_cond = 0.0838e-3;  %thickness of sheet metal that air side fins are made of 
densfin_cond = 850.;     %fin density, number of fins per one meter
aperp_cond = l_cond*gappl_cond - l_cond*densfin_cond*thfin_cond*lfin_cond;   %total area for air flow at minimum cross section
lp_cond = 1.e-3;         %louver pitch
lw_cond = 5e-3;          %width of louvers, can't be greater than lfin
theta_cond = -30.;       %degree, louver angle. Set negative to use simplified Chang's correlation
c1_cond = 1.0;           %Chang's louvered fin heat exchange correlation overall multiplier
c2_cond = 1.0;           %Chang's louvered fin heat exchange correlation, power of Re_lp multiplier
c3_cond = 0.023;         %Dittus-Boelter heat exchange correlation first coefficient (refrigerant side)
c4_cond = 0.8;           %Dittus-Boelter heat exchange correlation second coefficient (refrigerant side)
c5_cond = 8.0;           %Darcy-Weisbach pressure drop coefficient multiplier
tairin_cond = 303.16;    %incoming air temperature
vairin_cond = 2.0;       %incoming air flow velocity. Total air mass flow rate is vairin_cond*aperp_cond*air density*no.of plates
vairinmin_cond = 0.1;    %minimum airflow velocity, present even if fan is turned off
dpair_cond = 2300.;      %air pressure drop across condenser
k_ram = 0.1;             %This times vehicle velocity provides additional air velocity on condenser beyond that caused by fan
time_fanonoffvstime = [0 1e5];   %time vector for fan on/off signal lookup table
onoff_fanonoffvstime = [1  1];   %onoff signal vector for fan on/off signal lookup table
eff_fan = 0.15;          %efficiency number for condenser fan power calculation
ua_cond = 200.0;         %overall heat transfer coefficient
dmddp_cond = 5e-7;       %delta mass flow rate per delta p
qref_cond  = 0.05;       %reference mass flow rate, for heat exchange rate calculation

%condenser - line 1
nc1 = 35.;               %number of plates (flat tubes) in first pass
nseg_cond1 = 18.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_cond1 = 0.5e-4;  %dummy but needed
initmethod_cond1 = 0.0;  %dummy but needed
minit_cond1 = 1e-3;      %dummy but needed
tinit_cond1 = 293.16;    %dummy but needed
twinit_cond1 = 300.;     %initial refrigerant global uniform temperature.
minitvec_cond1 = 1e-4*ones(1,nseg_cond1);         %mass initialization vector. (dummy but needed)
iinitvec_cond1 = 0.0*ones(1,nseg_cond1+1);        %lin momentum init. vector. (dummy but needed)
einitvec_cond1 = 10.*ones(1,nseg_cond1);          %total energy init. vector. (dummy but needed)
twinitvec_cond1 = twinit_cond1*ones(1,nseg_cond1);%wall temperature init. vector.  
minitvec_cond1(1) = mdotglobal/nc1;   %initial mass flow rate
minitvec_cond1(2) = factor1;          %transport line convergence coeff 1
minitvec_cond1(3) = factor3;          %transport line convergence coeff 2

%condenser middle volume1
vol_condm1   = 0.1e-3;    %volume [m3]
pinit_condm1 = 20e5;      %initial pressure [Pa]. (not always, see initialization rules)
%tinit_condm1 = 345.0;     %initial temperature [K]. (not always, see initialization rules)
tinit_condm1 = bulkpervol*vol_condm1;    %artificial bulk modulus
hspecinit_condm1 = 3e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_condm1 = 0.3;     %initial liquid volume fraction. (not always, see initialization rules)

%condenser - line 2
nc2 = 9.0;               %number of plates (flat tubes) in second pass
nseg_cond2 = 18.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_cond2 = 0.5e-4;  %dummy but needed
initmethod_cond2 = 0.0;  %dummy but needed
minit_cond2 = 1e-3;      %dummy but needed
tinit_cond2 = 293.16;    %dummy but needed
twinit_cond2 = 300.0;    %initial refrigerant global uniform temperature. 
minitvec_cond2 = 1e-4*ones(1,nseg_cond2);         %mass initialization vector. (dummy but needed)
iinitvec_cond2 = 0.0*ones(1,nseg_cond2+1);        %lin momentum init. vector. (dummy but needed)
einitvec_cond2 = 10.*ones(1,nseg_cond2);          %total energy init. vector. (dummy but needed)
twinitvec_cond2 = twinit_cond2*ones(1,nseg_cond2);%wall temperature init. vector.  
minitvec_cond2(1) = mdotglobal/nc2;   %initial mass flow rate
minitvec_cond2(2) = factor1;          %transport line convergence coeff 1
minitvec_cond2(3) = factor3;          %transport line convergence coeff 2

%condenser downstream volume (receiver dryer)
vol_receiver = 0.325e-3;    %volume [m3]
pinit_receiver = 19.75e5;   %initial pressure [Pa]. (not always, see initialization rules)
%tinit_receiver = 329.0;     %initial temperature [K]. (not always, see initialization rules)
tinit_receiver = bulkpervol*vol_receiver;    %artificial bulk modulus
hspecinit_receiver = 2.6e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_receiver = 1.0;     %initial liquid volume fraction. (not always, see initialization rules)

%Thermostatic Expansion Valve with ball shaped throttling piece
cdfw_txv = 0.9;         %forward discharge coefficient
cdbk_txv = 0.9;         %backward discharge coefficient
kcd1_txv = 1.5;         %2-phase flow correction 1st coeff. - do not change
kcd2_txv = 2.0;         %2-phase flow correction 2nd coeff. - do not change
kcd3_txv = 1.3;         %2-phase flow correction 3rd coeff. - do not change
kcd4_txv = 1.1;         %2-phase flow correction 4th coeff. - do not change
s_txv = 0.8e-3;         %maximum displacement of throttling piece
smin_txv = 1e-6;        %minimum displacement of throttling piece, set positive to allow leakage
tchar_txv = 0.1;        %reciprocal of characteristic time for bulb temp response to step in equ. temperature
atop_txv = 400e-6;      %Equivalent area of actuator exposed to bulb pressure
apin_txv = 1e-3^2/4*pi; %area of guide on pin (piece between actuator and ball)
dball_txv = 3.0e-3;     %diameter of ball throttling piece
aseat_txv = dball_txv^2/4*pi;                       %area of ball seat
alpha_txv = pi/3.;                                  %full cone angle of ball seat
amax_txv = dball_txv*pi*s_txv*sin(alpha_txv/2.0);   %maximum flow area
rate_txv = 35e3;        %spring rate of spring
shset_txv = 6.0;        %superheat setting
pset_txv = 3.0e5;       %pressure at which superheat is set
tbulbinit_txv = 273.0;  %initial bulb temperature
%calculate spring preload to achieve a superheat setting of shset_txv
tset_txv = interp1(p_lookup_tsatvsp,t_lookup_tsatvsp,pset_txv);
psetbulb_txv = interp1(t_lookup_tsatvsp,p_lookup_tsatvsp,tset_txv+shset_txv);
fp_txv = (psetbulb_txv - pset_txv)*atop_txv - 15e5*aseat_txv;  %pin force neglected, dP_txv assumed 15 bar

%evaporator upstream volume
vol_evapu = 0.05e-3;     %volume [m3]
pinit_evapu = 1e5;       %initial pressure [Pa]. (not always, see initialization rules)
%tinit_evapu = 270.0;    %initial temperature [K]. (not always, see initialization rules)
tinit_evapu = bulkpervol*vol_evapu;    %artificial bulk modulus
hspecinit_evapu = 2.6e5; %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_evapu = 0.12;    %initial liquid volume fraction. (not always, see initialization rules)

%evaporator common input
nparch_evap = 1.0 ;      %number of parallel channels per plate (flat tube)
l_evap = 0.208;          %length of plates (dimension in the direction of refrigerant flow)
achan_evap = 52.08e-6;                      %refrigerant flow cross sectional area of parallel channels
pchan_evap = (2*18.6+2*2.8+4.*2.8)*1e-3;    %refrigerant side perimeter of parallel channels
relrough_evap = 0.01;    %relative roughness of the flat tube channels refrigerant side
mwall_evap = 0.037;      %dry mass of one plate including fins
cpwall_evap = 900.;      %specific heat of wall material (set for aluminum)
qcfactor_evap = 0.0;     %axial wall heat conduction coefficient
wplate_evap = 22.5e-3;   %plate width (dimension in air flow direction)
gappl_evap = 7.0e-3;     %distance between two plates / flat tubes
lfin_evap = 1.1*7.0e-3;  %length of one fin between two plates. Equals gappl for straigh 90 degree fin.
tp_evap = 9.0e-3;        %pitch of plates (top surface to top surface), has to be greater than gappl
thfin_evap = 0.076e-3;   %thickness of sheet metal that air side fins are made of 
densfin_evap = 1000/1.6; %fin density, number of fins per one meter  
lp_evap = 1.35e-3;       %louver pitch
lw_evap = 5e-3;          %width of louvers, can't be greater than lfin
theta_evap = -1.;        %degree, louver angle. Set negative to use simplified Chang's correlation
c1_evap = 2.0;           %Chang's louvered fin heat exchange correlation overall multiplier
c2_evap = 1.0;           %Chang's louvered fin heat exchange correlation, power of Re_lp multiplier
c3_evap = 0.023*2;       %Dittus-Boelter heat exchange correlation first coefficient (refrigerant side)
c4_evap = 2.0;           %Chen correlation overall multiplier
c5_evap = 20.;           %Darcy-Weisbach pressure drop coefficient multiplier
dpair_evap = 200.;       %evaporator air inlet pressure, after blower
relhum_cabin = 50.0;     %evaporator air inlet relative humidity 
dp_evaptocomp = 0.0;     %evaporator downstream to compressor suction pressure drop
dh_evaptocomp = 0.0;     %evaporator downstream to compressor suction enthalpy rise
eff_blower = 0.12;       %efficiency number for evaporator fan power calculation
ua_evap = 150.0;         %overall heat transfer coefficient
dmddp_evap = 1e-6;       %delta mass flow rate divided by delta P
qref_evap = 0.05;        %reference mass flow rate, for heat exchange rate calculation

%evaporator - pass 1
ne1 = 7.;                %number of plates (flat tubes)
nseg_evap1 = 10.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_evap1 = 0.5e-4;  %dummy but needed
initmethod_evap1 = 0.0;  %dummy but needed
minit_evap1 = 1e-3;      %dummy but needed
tinit_evap1 = 293.16;    %dummy but needed
twinit_evap1 = 300.;     %initial refrigerant global uniform temperature.
minitvec_evap1 = 1e-4*ones(1,nseg_evap1);         %mass initialization vector. (dummy but needed)
iinitvec_evap1 = 0.0*ones(1,nseg_evap1+1);        %lin momentum init. vector. (dummy but needed)
einitvec_evap1 = 10.*ones(1,nseg_evap1);          %total energy init. vector. (dummy but needed)
twinitvec_evap1 = twinit_evap1*ones(1,nseg_evap1);%wall temperature init. vector.  
minitvec_evap1(1) = mdotglobal/ne1;   %initial mass flow rate
minitvec_evap1(2) = factor1;          %plate line convergence coeff 1
minitvec_evap1(3) = factor3;          %plate line convergence coeff 2

%evaporator middle volume1
vol_evapm1   = 0.05e-3;   %volume [m3]
pinit_evapm1 = 1e5;       %initial pressure [Pa]. (not always, see initialization rules)
%tinit_evapm1 = 269.5;     %initial temperature [K]. (not always, see initialization rules)
tinit_evapm1 = bulkpervol*vol_evapm1;    %artificial bulk modulus
hspecinit_evapm1 = 3e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_evapm1 = 0.08;    %initial liquid volume fraction. (not always, see initialization rules)

%evaporator - Passes 2a and 2b
ne2a = 5.;               %number of plates (flat tubes) in Pass 2a
ne2b = 15.;              %number of plates (flat tubes) in Pass 2b
nseg_evap2 = 10.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_evap2 = 0.5e-4;  %dummy but needed
initmethod_evap2a = 0.0; %dummy but needed
minit_evap2a = 1e-3;     %dummy but needed
tinit_evap2a = 293.16;   %dummy but needed
twinit_evap2a = 300.0;   %initial refrigerant global uniform temperature.
minitvec_evap2a = 1e-4*ones(1,nseg_evap2);          %mass initialization vector. (dummy but needed)
iinitvec_evap2a = 0.0*ones(1,nseg_evap2+1);         %lin momentum init. vector. (dummy but needed)
einitvec_evap2a = 10.*ones(1,nseg_evap2);           %total energy init. vector. (dummy but needed)
twinitvec_evap2a = twinit_evap2a*ones(1,nseg_evap2);%wall temperature init. vector.  
minitvec_evap2a(1) = mdotglobal/ne2a;   %initial mass flow rate
minitvec_evap2a(2) = factor1;          %plate line convergence coeff 1
minitvec_evap2a(3) = factor3;          %plate line convergence coeff 2
initmethod_evap2b = 0.0;  %dummy but needed
minit_evap2b = 1e-3;      %dummy but needed
tinit_evap2b = 293.16;    %dummy but needed
twinit_evap2b = 300.0;    %initial refrigerant global uniform temperature.
minitvec_evap2b = 1e-4*ones(1,nseg_evap2);          %mass initialization vector. (dummy but needed)
iinitvec_evap2b = 0.0*ones(1,nseg_evap2+1);         %lin momentum init. vector. (dummy but needed)
einitvec_evap2b = 10.*ones(1,nseg_evap2);           %total energy init. vector. (dummy but needed)
twinitvec_evap2b = twinit_evap2b*ones(1,nseg_evap2);%wall temperature init. vector.  
minitvec_evap2b(1) = mdotglobal/ne2b;   %initial mass flow rate
minitvec_evap2b(2) = factor1;          %plate line convergence coeff 1
minitvec_evap2b(3) = factor3;          %plate line convergence coeff 2

%evaporator middle volume2
vol_evapm2   = 0.05e-3;   %volume [m3]
pinit_evapm2 = 1e5;       %initial pressure [Pa]. (not always, see initialization rules)
%tinit_evapm2 = 269.0;     %initial temperature [K]. (not always, see initialization rules)
tinit_evapm2 = bulkpervol*vol_evapm2;    %artificial bulk modulus
hspecinit_evapm2 = 3e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_evapm2 = 0.05;    %initial liquid volume fraction. (not always, see initialization rules)

%evaporator - pass3
ne3 = 12.;               %number of plates (flat tubes)
nseg_evap3 = 10.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_evap3 = 0.5e-4;  %dummy but needed
initmethod_evap3 = 0.0;  %dummy but needed
minit_evap3 = 1e-3;      %dummy but needed
tinit_evap3 = 293.16;    %dummy but needed
twinit_evap3 = 300.0;    %initial refrigerant global uniform temperature.
minitvec_evap3 = 1e-4*ones(1,nseg_evap3);         %mass initialization vector. (dummy but needed)
iinitvec_evap3 = 0.0*ones(1,nseg_evap3+1);        %lin momentum init. vector. (dummy but needed)
einitvec_evap3 = 10.*ones(1,nseg_evap3);          %total energy init. vector. (dummy but needed)
twinitvec_evap3 = twinit_evap3*ones(1,nseg_evap3);%wall temperature init. vector.  
minitvec_evap3(1) = mdotglobal/ne3;   %initial mass flow rate
minitvec_evap3(2) = factor1;          %plate line convergence coeff 1
minitvec_evap3(3) = factor3;          %plate line convergence coeff 2

%evaporator middle volume3
vol_evapm3   = 0.05e-3;   %volume [m3]
pinit_evapm3 = 1e5;       %initial pressure [Pa]. (not always, see initialization rules)
%tinit_evapm3 = 268.5;     %initial temperature [K]. (not always, see initialization rules)
tinit_evapm3 = bulkpervol*vol_evapm3;    %artificial bulk modulus
hspecinit_evapm3 = 3e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_evapm3 = 0.03;    %initial liquid volume fraction. (not always, see initialization rules)

%evaporator - pass4
ne4 = 15.;               %number of plates (flat tubes)
nseg_evap4 = 10.0;       %number of finite volumes (computational segments) in one channel of one plate
damping_evap4 = 0.5e-4;  %dummy but needed
initmethod_evap4 = 0.0;  %dummy but needed
minit_evap4 = 1e-3;      %dummy but needed
tinit_evap4 = 293.16;    %dummy but needed
twinit_evap4 = 300.0;    %initial refrigerant global uniform temperature.
minitvec_evap4 = 1e-4*ones(1,nseg_evap4);         %mass initialization vector. (dummy but needed)
iinitvec_evap4 = 0.0*ones(1,nseg_evap4+1);        %lin momentum init. vector. (dummy but needed)
einitvec_evap4 = 10.*ones(1,nseg_evap4);          %total energy init. vector. (dummy but needed)
twinitvec_evap4 = twinit_evap4*ones(1,nseg_evap4);%wall temperature init. vector.  
minitvec_evap4(1) = mdotglobal/ne4;   %initial mass flow rate
minitvec_evap4(2) = factor1;          %plate line convergence coeff 1
minitvec_evap4(3) = factor3;          %plate line convergence coeff 2

%Evaporator downstream volume
vol_evapd = 0.1e-3;      %volume [m3]
pinit_evapd = 1e5;       %initial pressure [Pa]. (not always, see initialization rules)
%tinit_evapd = 268.0;     %initial temperature [K]. (not always, see initialization rules)
tinit_evapd = bulkpervol*vol_evapd;    %artificial bulk modulus
hspecinit_evapd = 4.1e5;   %initial spec enthalpy [J/kg]. (not always, see initialization rules)
lvfinit_evapd = 0.1;     %initial liquid volume fraction. (not always, see initialization rules)

%compressor
tdel_cycling = 5.0;      %hold clutch disengaged or engaged at least this long after every switch
tdelinit_cycling = 1.0;  %initial setting for cycling: 1:compressor on, 0: compressor off
time_rpmvstime = [0,    10000];  %time for rpm vs. time lookup table.  Matters only if ifmech = 1.0
rpm_rpmvstime =  [1600,  1600];  %compressor drive rpm for rpm vs. time lookup table.  Matters only if ifmech = 1.0
load rpmvstimeSCO3
displ_compr = 0.200e-3;  %volumetric displacement per revolution [m3/sec]
rpm_max = 7000.;         %maximum RPM.  Matters only if ifmech = 0.0
rpm_minmaxrat = 1500./7000.;                 %ratio of minimum to maximum RPM. Matters only if ifmech = 0.0
rpm_switchoff = rpm_max*rpm_minmaxrat*1.01;  %low RPM at which the compressor cycles off. Matters only if ifmech = 0.0
ratio_compr = 1.37;      %drive ratio, engine RPM times this is compressor RPM.  Matters only if ifmech = 1.0
voleff_prs  =   [3     4     5     6     7     8     9    10];                 %vector of pressure ratios for efficiency lookup tables
voleff_rpms =   [1000   1300   1600   1900  2200  2500   2800   3100   3400];  %vector of RPMs for efficiency lookup tables
voleff_rpm_pr = ...         %volumetric efficiency vs. RPM and pressure ratio table
   [0.6740    0.6740    0.6561    0.6322    0.5916    0.5649    0.5389    0.5126    0.5126;...
    0.6740    0.6740    0.6561    0.6322    0.5916    0.5649    0.5389    0.5126    0.5126;...
    0.6508    0.6508    0.6328    0.6147    0.5916    0.5649    0.5389    0.5126    0.5126;...
    0.6254    0.6254    0.6105    0.5924    0.5697    0.5432    0.5172    0.4913    0.4913;...
    0.5996    0.5996    0.5871    0.5700    0.5479    0.5217    0.4956    0.4705    0.4705;...
    0.5738    0.5738    0.5613    0.5481    0.5260    0.4998    0.4748    0.4497    0.4497;...
    0.5483    0.5483    0.5356    0.5204    0.4994    0.4783    0.4539    0.4289    0.4289;...
    0.5483    0.5483    0.5356    0.5204    0.4994    0.4783    0.4539    0.4289    0.4289];
iseff_rpm_pr = ...          %isentropic efficiency vs. RPM and pressure ratio table
   [0.8490    0.8490    0.7829    0.7409    0.7065    0.6802    0.6435    0.6042    0.6042;...
    0.8490    0.8490    0.7829    0.7409    0.7065    0.6802    0.6435    0.6042    0.6042;...
    0.8576    0.8576    0.8108    0.7482    0.7065    0.6802    0.6435    0.6042    0.6042;...
    0.8258    0.8258    0.8224    0.7599    0.7198    0.7016    0.6651    0.6176    0.6176;...
    0.8396    0.8396    0.8057    0.7715    0.7331    0.6952    0.6317    0.6207    0.6207;...
    0.8482    0.8482    0.8195    0.7850    0.7464    0.6457    0.6348    0.6239    0.6239;...
    0.8156    0.8156    0.7929    0.7667    0.7360    0.7053    0.6656    0.6270    0.6270;...
    0.8156    0.8156    0.7929    0.7667    0.7360    0.7053    0.6656    0.6270    0.6270];     
md_comprmax  =   rpm_max/60.*displ_compr*0.975*27.8;   %maximum mass flow rate for mech.eff. calc. Matters only if ifmech = 0.0
c1_comprmech = 0.9;      %mechanical efficiency 1st (linear) coeff
c2_comprmech = 0.0;      %mechanical efficiency 2nd (non-linear) coeff
f1_comprcontr = -0.02;   %first PI controller coefficient - effects both P and I. Matters only if ifmech = 0
f2_comprcontr = 1./6.;   %second PI controller coefficient - effects both P and I.  Matters only if ifmech = 0

load initstates          %Overwrite initialization to state variables